@@ -1,9 +1,13 @@
-#  Copyright © 2021 Ingram Micro Inc. All rights reserved.
+#  Copyright © 2022 Ingram Micro Inc. All rights reserved.
 
 import sys
 
 from dj_cqrs.constants import NO_QUEUE
-from dj_cqrs.management.commands.cqrs_sync import Command as SyncCommand
+from dj_cqrs.management.commands.cqrs_sync import (
+    Command as SyncCommand,
+    DEFAULT_BATCH,
+    DEFAULT_PROGRESS,
+)
 from dj_cqrs.registries import MasterRegistry
 
 from django.core.management.base import BaseCommand, CommandError
@@ -12,7 +16,23 @@ from django.core.management.base import BaseCommand, CommandError
 class Command(BaseCommand):
     help = 'Diff synchronizer from CQRS replica stream.'
 
+    def add_arguments(self, parser):
+        parser.add_argument(
+            '--batch', '-b',
+            help='Batch size',
+            type=int,
+            default=DEFAULT_BATCH,
+        )
+        parser.add_argument(
+            '--progress', '-p',
+            help='Display progress',
+            action='store_true',
+        )
+
     def handle(self, *args, **options):
+        progress = self._get_progress(options)
+        batch_size = self._get_batch_size(options)
+
         with sys.stdin as f:
             first_line = f.readline().strip()
             model = self._get_model(first_line)
@@ -22,6 +42,8 @@ class Command(BaseCommand):
                 sync_kwargs = {
                     'cqrs_id': model.CQRS_ID,
                     'filter': '{{"id__in": {0}}}'.format(pks_line.strip()),
+                    'progress': progress,
+                    'batch': batch_size,
                 }
                 if queue:
                     sync_kwargs['queue'] = queue
@@ -43,3 +65,11 @@ class Command(BaseCommand):
         queue = first_line.split(',')[-1]
         if queue != NO_QUEUE:
             return queue
+
+    @staticmethod
+    def _get_batch_size(options):
+        return options.get('batch', DEFAULT_BATCH)
+
+    @staticmethod
+    def _get_progress(options):
+        return bool(options.get('progress', DEFAULT_PROGRESS))
